# --------------------------------------------------------------------------
#                        整体结构模型（动力）                             
# --------------------------------------------------------------------------


# Set up -------------------------------------------------------------------
wipe analysis;
model BasicBuilder -ndm 2 -ndf 3;
set dataDir data_Reference;
file mkdir $dataDir; 

# Define units--------------------------------------------------------------
set m 1.; 				
set N  1.; 			
set sec 1.; 			
set mm [expr $m/1000];
set kN [expr $N*1000];
set MPa [expr $N/pow($mm,2)];
set mm2 [expr $mm*$mm]; 
set mm4 [expr pow($mm,4)]; 	
set PI [expr 2*asin(1.0)]; 		
set g [expr 9.807*$m/pow($sec,2)]; 
set kg [expr 9.807*$N/$g];

# Define nodes and constraints-----------------------------------------------
set LCol [expr 3.6*$m];
set LBeam [expr 6*$m];   

set X0 0.;
set X1 [expr $X0 + $LBeam];
set Y0 0.;
set Y1 [expr $Y0 + $LCol];
set Y2 [expr $Y1 + $LCol];

node 11 $X0 $Y0;
node 12 $X1 $Y0;
node 21 $X0 $Y1;
node 22 $X1 $Y1;
node 31 $X0 $Y2;
node 32 $X1 $Y2;

# Boundary conditions
fix 11 1 1 1;
fix 12 1 1 1;

# Rigid beams
equalDOF 21 22 1;
equalDOF 31 32 1;
fix 21 0 1 1;
fix 22 0 1 1;
fix 31 0 1 1;
fix 32 0 1 1;
# rigidLink beam 21 22;
# rigidLink beam 31 32;


# Define material and element-------------------------------------------------
set matID 1;      
set Fy [expr 235*$MPa];         # yield strength 
set Es [expr 2e5*$MPa];    # Young's modulus
set bs 0.05;                    # strain-hardening ratio  

uniaxialMaterial Steel01 $matID $Fy $Es $bs;

# Define sections ------------------------------------------------------------
# Column section : H300×300×10×15
set secID 1;
set dCol [expr 300*$mm];
set bCol [expr 300*$mm];
set tw [expr 10*$mm];
set tf [expr 15*$mm];

set dw [expr $dCol-2*$tf];
set cy1 [expr -$dCol/2];
set cy2 [expr -$dw/2];
set cy3 [expr  $dw/2];
set cy4 [expr  $dCol/2];

set cz1 [expr -$bCol/2];
set cz2 [expr -$tw/2];
set cz3 [expr  $tw/2];
set cz4 [expr  $bCol/2];

section Fiber $secID { 
	patch quadr  $matID  2 20   $cy1 $cz4   $cy1 $cz1   $cy2 $cz1   $cy2 $cz4
   	patch quadr  $matID  20 2   $cy2 $cz3   $cy2 $cz2   $cy3 $cz2   $cy3 $cz3
   	patch quadr  $matID  2 20   $cy3 $cz4   $cy3 $cz1   $cy4 $cz1   $cy4 $cz4
}
	
# Define elements -------------------------------------------------------------
geomTransf Linear 1;

set np 5;
element nonlinearBeamColumn 101 11 21 $np $secID 1;
element nonlinearBeamColumn 102 12 22 $np $secID 1;
element nonlinearBeamColumn 201 21 31 $np $secID 1;
element nonlinearBeamColumn 202 22 32 $np $secID 1;

# Define mass------------------------------------------------------------------
set mass1 [expr 40000*$kg];
set mass2 [expr 40000*$kg];
mass 21 $mass1 1e-9 1e-9;
mass 31 $mass2 1e-9 1e-9;

# Define damping ---------------------------------------------------------------
set xdamp 0.03;					
set lambda [eigen -fullGenLapack 1];
# set lambda [eigen 1];
set omega [expr pow([lindex $lambda 0],0.5)];
set alpham [expr $xdamp*$omega];
set betak [expr $xdamp/$omega]; 
set period [expr 2.0*$PI/$omega];
set outFile [open $dataDir/period.txt w]
puts $outFile "omega=$omega; period=$period";
close $outFile;

rayleigh $alpham 0 $betak 0;			

# Apply gravity ---------------------------------------------------------------
set P [expr -200*$kN];
pattern Plain 10001 Linear {
	load 21 0 $P 0;
	load 22 0 $P 0;
	load 31 0 $P 0;
	load 32 0 $P 0;
}
		
constraints Penalty 1E+20 1E+20;    		
numberer Plain;			
system BandGeneral;		
test EnergyIncr 1.e-8 50 0; 
algorithm Linear 0.7;	
integrator LoadControl 0.1;
analysis Static;
analyze 10;
loadConst -time 0.0;

# Define recorders -------------------------------------------------------------
# Node
recorder Node -file $dataDir/Disp.txt -time -node 21 22 31 32 -dof 1 2 3 disp;
recorder Node -file $dataDir/Force.txt -time -node 21 22 31 32 -dof 1 2 3 reaction;

recorder Node -file $dataDir/Disp1.txt -node 21 -dof 1 disp;

# Element - 101
recorder Element -file $dataDir/eleForce.txt -time -ele 101 globalForce;

# Apply excitation -------------------------------------------------------------
set IDloadTag 400;
set GMdirection 1;
set GMfile "ELC180_0.005_50s.txt";
set dt 0.005;
set scale 1;
set accelSeries "Path -dt $dt -filePath $GMfile -factor $scale";
pattern UniformExcitation  $IDloadTag  $GMdirection -accel $accelSeries;

constraints Plain;
system BandGeneral;
# integrator CentralDifference;
integrator Newmark 0.5 0.25;
analysis Transient;
analyze 9999 $dt;












